h1,
h2,
h3,
h4,
h5,
h6 {
  margin: 10px 0;
  color: #666666;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
h1 {
  font-size: 40px;
  font-weight: 500;
  line-height: 60px;
  color: #666666;
}
h2 {
  font-size: 36px;
  font-weight: 300;
  line-height: 40px;
}
h3 {
  font-size: 28px;
  font-weight: 300;
  line-height: 36px;
}
h4 {
  font-size: 28px;
  font-weight: 500;
  line-height: 36px;
}
h5 {
  font-size: 20px;
  font-weight: 300;
  line-height: 28px;
}
h6 {
  font-size: 20px;
  font-weight: 500;
  line-height: 28px;
}
p {
  font-size: 15px;
  color: #666666;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
html {
  height: 100%;
}
body {
  height: 100%;
}
#app-header .tethys-app-header {
  position: fixed;
  background: #1b95dc;
  height: 100px;
  width: 100%;
  z-index: 100;
  margin-top: -100px;
}
#app-header .tethys-app-header.show-header {
  margin-top: 0;
}
#app-header .tethys-app-header.with-transition {
  -webkit-transition: margin 0.4s ease;
  -moz-transition: margin 0.4s ease;
  -o-transition: margin 0.4s ease;
  -ms-transition: margin 0.4s ease;
  transition: margin 0.4s ease;
}
#app-header .tethys-app-header .icon-wrapper {
  position: absolute;
  top: 0;
  left: 0;
  padding: 20px;
  z-index: 100;
  margin-left: 30px;
  padding: 10px;
}
#app-header .tethys-app-header .icon-wrapper img {
  height: 80px;
  border-radius: 50%;
  background: #1b95dc;
}
#app-header .tethys-app-header .app-title-wrapper {
  float: left;
}
#app-header .tethys-app-header .app-title-wrapper .app-title {
  display: block;
  padding: 20px 0;
  padding-left: 130px;
  font-size: 40px;
  color: white;
  font-weight: 300;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  width: 1700px;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}
#app-header .tethys-app-header .exit-button {
  float: right;
  margin-right: 50px;
  margin-top: 26px;
}
#app-header .tethys-app-header .exit-button a {
  display: block;
  padding: 10px 20px;
  border-radius: 5px;
  background: rgba(255, 255, 255, 0.1);
  color: #ffffff;
  font-size: 20px;
  font-weight: 400;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
#app-header .tethys-app-header .exit-button a:hover {
  background: rgba(0, 0, 0, 0.1);
  text-decoration: none;
}
#app-header .tethys-app-header .toggle-nav {
  display: block;
  height: 40px;
  width: 15px;
  float: left;
  padding: 10px;
  padding-left: 0;
  margin: 30px 0;
  margin-right: 5px;
  border-radius: 0 5px 5px 0;
}
#app-header .tethys-app-header .toggle-nav div {
  height: 3px;
  background-color: #ffffff;
  margin-bottom: 5px;
  border-radius: 5px;
}
#app-header .tethys-app-header .toggle-nav div:last-child {
  margin-bottom: 0;
}
#app-header .tethys-app-header .toggle-nav:hover {
  background: rgba(0, 0, 0, 0.3);
}
#app-content-wrapper {
  position: relative;
  overflow: hidden;
  width: 100%;
  min-height: 100%;
}
#app-content-wrapper #app-content {
  position: relative;
  width: 100%;
  padding: 50px;
  padding-top: 120px;
  padding-bottom: 90px;
  min-height: 100%;
  -webkit-transform: translateX(0);
  -moz-transform: translateX(0);
  -ms-transform: translateX(0);
  -o-transform: translateX(0);
  transform: translateX(0);
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
  -ms-transform: translate3d(0, 0, 0);
  -o-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0);
  visibility: hidden;
  opacity: 0;
}
#app-content-wrapper #app-content.show-app-content {
  visibility: visible;
  opacity: 1;
}
#app-content-wrapper #app-content.with-transition {
  -webkit-transition: visibility 0.2s ease 0.5s;
  -moz-transition: visibility 0.2s ease 0.5s;
  -o-transition: visibility 0.2s ease 0.5s;
  -ms-transition: visibility 0.2s ease 0.5s;
  transition: visibility 0.2s ease 0.5s;
  -webkit-transition: opacity 0.2s ease 0.5s;
  -moz-transition: opacity 0.2s ease 0.5s;
  -o-transition: opacity 0.2s ease 0.5s;
  -ms-transition: opacity 0.2s ease 0.5s;
  transition: opacity 0.2s ease 0.5s;
}
#app-content-wrapper #app-content #app-navigation {
  position: absolute;
  top: 0;
  left: -300px;
  width: 300px;
  height: 100%;
  background: #efefef;
  padding: 0 15px;
  padding-top: 100px;
}
#app-content-wrapper #app-content #app-navigation .nav {
  padding: 20px 0;
  padding-bottom: 40px;
  height: 100%;
  overflow: auto;
}
#app-content-wrapper #app-content #app-navigation .nav::-webkit-scrollbar {
  display: none;
}
#app-content-wrapper #app-content #app-navigation .nav li a {
  color: #1b95dc;
}
#app-content-wrapper #app-content #app-navigation .nav li a:hover {
  background: #ffffff;
  text-decoration: none;
}
#app-content-wrapper #app-content #app-navigation .nav li.title {
  padding: 10px 15px;
  padding-top: 15px;
  font-size: 20px;
  font-weight: 500;
  color: #444444;
  -webkit-font-smoothing: antialiasing;
}
#app-content-wrapper #app-content #app-navigation .nav li.separator {
  margin: 20px 15px;
}
#app-content-wrapper #app-content #app-navigation .nav li.active a {
  color: white;
  background: #1b95dc;
}
#app-content-wrapper #app-content #app-actions {
  position: absolute;
  width: 100%;
  bottom: 0;
  right: 0;
  padding: 20px 50px;
}
#app-content-wrapper #app-content #app-actions .separator {
  border-top: 1px solid #DDDDDD;
  margin-bottom: 20px;
}
#app-content-wrapper #app-content #app-actions .btn {
  float: right;
  margin-left: 10px;
  padding: 10px 20px;
}
#app-content-wrapper.show-nav #app-content {
  padding-right: 350px;
  -webkit-transform: translateX(-300px);
  -moz-transform: translateX(-300px);
  -ms-transform: translateX(-300px);
  -o-transform: translateX(-300px);
  transform: translateX(-300px);
  -webkit-transform: translate3d(300px, 0, 0);
  -moz-transform: translate3d(300px, 0, 0);
  -ms-transform: translate3d(300px, 0, 0);
  -o-transform: translate3d(300px, 0, 0);
  transform: translate3d(300px, 0, 0);
}
#app-content-wrapper.show-nav #app-content #app-actions {
  padding-right: 350px;
}
#app-content-wrapper.with-transition #app-content {
  -webkit-transition: 0.2s ease-in-out all;
  -moz-transition: 0.2s ease-in-out all;
  -o-transition: 0.2s ease-in-out all;
  -ms-transition: 0.2s ease-in-out all;
  transition: 0.2s ease-in-out all;
}
#app-content-wrapper.with-transition #app-content #app-actions {
  -webkit-transition: 0.2s ease-in-out padding;
  -moz-transition: 0.2s ease-in-out padding;
  -o-transition: 0.2s ease-in-out padding;
  -ms-transition: 0.2s ease-in-out padding;
  transition: 0.2s ease-in-out padding;
}
@media (max-width: 1900px) {
  #app-header .tethys-app-header .app-title-wrapper .app-title {
    width: 1500px;
  }
}
@media (max-width: 1700px) {
  #app-header .tethys-app-header .app-title-wrapper .app-title {
    width: 1300px;
  }
}
@media (max-width: 1500px) {
  #app-header .tethys-app-header .app-title-wrapper .app-title {
    width: 1100px;
  }
}
@media (max-width: 1300px) {
  #app-header .tethys-app-header .app-title-wrapper .app-title {
    width: 900px;
  }
}
@media (max-width: 1100px) {
  #app-header .tethys-app-header .app-title-wrapper .app-title {
    width: 700px;
  }
}
@media (max-width: 900px) {
  #app-header .tethys-app-header .app-title-wrapper .app-title {
    width: 500px;
  }
  #app-content-wrapper.show-nav #app-content {
    padding-right: 50px;
  }
  #app-content-wrapper.show-nav #app-content #app-actions {
    padding-right: 50px;
  }
}
@media (max-width: 700px) {
  #app-header .tethys-app-header .icon-wrapper {
    padding: 20px;
    padding-left: 0px;
  }
  #app-header .tethys-app-header .icon-wrapper img {
    height: 60px;
  }
  #app-header .tethys-app-header .app-title-wrapper .app-title {
    padding: 29px 0;
    padding-left: 100px;
    font-size: 30px;
    width: 350px;
  }
}
@media (max-width: 500px) {
  #app-header .tethys-app-header {
    height: 60px;
  }
  #app-header .tethys-app-header .toggle-nav {
    margin: 10px;
    margin-left: 0;
  }
  #app-header .tethys-app-header .icon-wrapper {
    padding: 10px;
    padding-left: 0;
  }
  #app-header .tethys-app-header .icon-wrapper img {
    height: 40px;
  }
  #app-header .tethys-app-header .app-title-wrapper .app-title {
    padding: 13px 0;
    padding-left: 65px;
    font-size: 24px;
    width: 230px;
  }
  #app-header .tethys-app-header .exit-button {
    margin-right: 20px;
    margin-top: 10px;
  }
  #app-header .tethys-app-header .exit-button a {
    padding: 6px 15px;
  }
  #app-content-wrapper #app-content {
    padding-top: 80px;
  }
}
