@import "vendor/prefixer";
@import "mixins";
@import "secondary_header.less";

// Transitions
@curtain-transition-duration: 0.3s;
@curtain-transition-delay: 0.1;
@curtain-transition-type: ease-out;

body {
  background: #efefef;
}

.header-wrapper {
  margin-top: -90px;

  &.show {
    margin-top: 0px;
  }

  &.with-transition {
    .transition(margin 0.4s ease);
  }
}

.tethys-secondary-header {
  height: 100px;
  margin-top: -300px;
  margin-bottom: 350px;

  &.show {
    margin-top: 0;
    margin-bottom: 50px;
  }

  &.with-transition {
    .transition(margin 0.4s ease);
  }

  .secondary-title-wrapper {

    .secondary-title {
      padding-top: 21px;
      font-size: 40px;
    }
  }

  .image-wrapper {
    padding-left: 50px;

    img {
      width: 120px;
    }
  }
}

.no-apps-loaded-message {
  width: 50%;
  margin: 100px auto;
  margin-bottom: 150px;
  text-align: center;
}

#app-list {
  position: relative;
  margin: 0 auto;
  width: 1200px;

  .app-container {
    width: 200px;
    margin: 20px;
    background: #ffffff;
    border-radius: 5px;
    box-shadow: 0 0 5px 0 rgba(0, 0, 0, 0.1);

    .app-icon {

      img {
        width: 170px;
        margin: 15px;
      }
    }

    .app-title {
      width: 100%;
      padding: 15px;
      padding-top: 0;
      color: #666666;
      text-align: center;
      font-size: 20px;
      font-weight: 500;
      border-radius: 0 0 5px 5px;
      .font-smoothing()

    }

    .color-effect {
      display: none;
      content: " ";
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      border-radius: 5px;
      background: rgba(255, 255, 255, 0.15);
    }

    &:hover {
      box-shadow: 0px 0 10px 0 rgba(0, 0, 0, 0.1);
      text-decoration: none;

      .color-effect {
        display: block;
      }
    }
  }
}

#app-library-curtain {
    position: fixed;
    top: 0;
    left: 0;
    background-color: rgba(255, 255, 255, 0);
    width: 100%;
    height: 100%;
    z-index: -1;
    .transition(background-color @curtain-transition-type @curtain-transition-duration @curtain-transition-delay);


    &.show {
        background-color: rgba(255, 255, 255, 1);
        z-index: 200;
    }
}

@media (max-width: 1200px) {
  #app-list {
    width: 960px;
  }
}

@media (max-width: 960px) {
  #app-list {
    width: 720px;
  }
}

@media (max-width: 720px) {
  #app-list {
    width: 480px;
  }
}

@media (max-width: 700px) {
.tethys-secondary-header {
  height: 100px;
  margin-bottom: 0;

  &.hide {
    margin-top: -300px;
    margin-bottom: 300px;
  }

  .secondary-title-wrapper {

    .secondary-title {
      padding-left: 120px;
    }
  }

  .image-wrapper {
    position: inline-block;
    padding: 10px 20px;

    img {
      width: 80px;
    }
  }
}

}

@media (max-width: 480px) {
  #app-list {
    width: 240px;
  }
}